mchammer.Optimizer
==================

.. currentmodule:: mchammer

.. autoclass:: Optimizer
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Optimizer.compute_potential
      ~Optimizer.get_result
      ~Optimizer.get_trajectory
   
   

   
   
   